/*
 * Copyright (C) 2005-2009 Alex Murray <murray.alex@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef ACTIVE_SESNOR_LIBNOTIFY_H
#define ACTIVE_SENSOR_LIBNOTIFY_H

#include "sensors-applet.h"
#include "active-sensor.h"

void active_sensor_libnotify_notify(ActiveSensor *active_sensor,
                                    NotifType notif_type,
                                    const gchar *summary,
                                    const gchar *message,
				    const gchar *icon_filename,
                                    gint timeout_msecs);
void active_sensor_libnotify_notify_end(ActiveSensor *active_sensor,
                                        NotifType notif_type);

#endif /* SENSORS_APPLET_LIBNOTIFY_H */
